@@ -13,11 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-try:
-    # For Python 3.8 and later
-    import importlib.metadata as importlib_metadata
-except ImportError:
-    # For everyone else
-    import importlib_metadata
+import importlib.metadata
 
-__version__ = importlib_metadata.version("osprofiler")
+__version__ = importlib.metadata.version("osprofiler")
